@@ -5,7 +5,7 @@ use crate::{backend::SchemaBuilder, prepare::*, types::*, SchemaStatementBuilder
 /// # Examples
 ///
 /// ```
-/// use sea_query::{*, tests_cfg::*};
+/// use sea_query::{tests_cfg::*, *};
 ///
 /// let table = Table::drop()
 ///     .table(Glyph::Table)
@@ -84,8 +84,8 @@ impl TableDropStatement {
 
     pub fn take(&mut self) -> Self {
         Self {
-            tables: std::mem::replace(&mut self.tables, Vec::new()),
-            options: std::mem::replace(&mut self.options, Vec::new()),
+            tables: std::mem::take(&mut self.tables),
+            options: std::mem::take(&mut self.options),
             if_exists: self.if_exists,
         }
     }
