@@ -118,6 +118,8 @@ pub enum BinOper {
     Contains,
     #[cfg(feature = "backend-postgres")]
     Contained,
+    #[cfg(feature = "backend-postgres")]
+    Concatenate,
 }
 
 /// Logical chain operator
@@ -146,7 +148,7 @@ pub struct OrderExpr {
 /// Join on types
 #[derive(Debug, Clone)]
 pub enum JoinOn {
-    Condition(Box<SimpleExpr>),
+    Condition(Box<ConditionHolder>),
     Columns(Vec<SimpleExpr>),
 }
 
@@ -309,6 +311,12 @@ impl Iden for Alias {
 
 impl NullAlias {
     pub fn new() -> Self {
+        Self::default()
+    }
+}
+
+impl Default for NullAlias {
+    fn default() -> Self {
         Self
     }
 }
